@@ -913,7 +913,7 @@ class MiniRpaSapAutomation:
             except NoSuchElementException:
                 pass
             else:
-                if session_name_element.text.strip() == session_name:
+                if session_name_element.text.strip().upper() == session_name.upper():
                     has_search_result = True
 
         if has_search_result:
